@@ -9,6 +9,13 @@ Various Python helpers.
 
 
 import os
+import platform
+
+_platform = platform.system().lower()
+
+is_osx = (_platform == 'darwin')
+is_win = (_platform == 'windows')
+is_lin = (_platform == 'linux')
 
 
 def find_path_above(*names):
@@ -23,3 +30,4 @@ def find_path_above(*names):
                 return os.path.abspath(joined)
         path = os.path.join('..', path)
 
+
